<?php

namespace Drupal\accessibility_menu\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * AccessibilityMenu settings form.
 */
class AccessibilityMenuSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'accessibility_menu.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'accessibility_menu_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $default = $this->config('accessibility_menu.settings')->get();
    $values = array_replace_recursive($default, $form_state->getValue('fields') ?? []);

    $form['fields'] = [
      '#type' => 'container',
      '#tree' => TRUE,
    ];
    $form['fields']['enabled'] = [
      '#type'          => 'checkbox',
      '#title'         => $this->t('Enable'),
      '#default_value' => $values['enabled'] ?? FALSE,
    ];
    $form['actions'] = [
      '#type'  => 'actions',
      'submit' => [
        '#type'        => 'submit',
        '#value'       => $this->t('Save'),
        '#button_type' => 'primary,',
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $values = $form_state->getValue('fields');
    $config = $this->config('accessibility_menu.settings');
    foreach ($values as $key => $value) {
      $config->set($key, $value);
    }
    $config->save();
  }

}
